@@ -719,6 +719,8 @@ struct tds_column
 	unsigned char column_computed:1;
 	TDS_UCHAR column_collation[5];
 
+	unsigned char use_iconv_out:1;
+
 	/* additional fields flags for compute results */
 	TDS_SMALLINT column_operand;
 	TDS_TINYINT column_operator;
@@ -1113,7 +1115,7 @@ struct tds_connection
 	TDS_UCHAR tds72_transaction[8];
 
 	TDS_CAPABILITIES capabilities;
-	unsigned int use_iconv:1;
+	unsigned int use_iconv_in:1;
 	unsigned int tds71rev1:1;
 	unsigned int pending_close:1;	/**< true is connection has pending closing (cursors or dynamic) */
 	unsigned int encrypt_single_packet:1;
